@@ -74,12 +74,12 @@ Session *TermWidgetImpl::createSession(QWidget* parent)
 
     session->setTitle(Session::NameRole, QLatin1String("QTermWidget"));
 
-    /* Thats a freaking bad idea!!!!
+    /* That's a freaking bad idea!!!!
      * /bin/bash is not there on every system
      * better set it to the current $SHELL
      * Maybe you can also make a list available and then let the widget-owner decide what to use.
      * By setting it to $SHELL right away we actually make the first filecheck obsolete.
-     * But as iam not sure if you want to do anything else ill just let both checks in and set this to $SHELL anyway.
+     * But as I'm not sure if you want to do anything else I'll just let both checks in and set this to $SHELL anyway.
      */
     //session->setProgram("/bin/bash");
 
@@ -470,6 +470,11 @@ void QTermWidget::setColorScheme(const QString& origName)
     m_impl->m_terminalDisplay->setColorTable(table);
 }
 
+QStringList QTermWidget::getAvailableColorSchemes()
+{
+   return QTermWidget::availableColorSchemes();
+}
+
 QStringList QTermWidget::availableColorSchemes()
 {
     QStringList ret;
@@ -814,3 +819,8 @@ void QTermWidget::setConfirmMultilinePaste(bool confirmMultilinePaste) {
 void QTermWidget::setTrimPastedTrailingNewlines(bool trimPastedTrailingNewlines) {
     m_impl->m_terminalDisplay->setTrimPastedTrailingNewlines(trimPastedTrailingNewlines);
 }
+
+QTermWidgetInterface* QTermWidget::createWidget(int startnow) const
+{
+   return new QTermWidget(startnow);
+}
